@@ -2,11 +2,7 @@
 
 from sphinx_testing import with_app
 
-import sys
-if sys.version_info < (2, 7):
-    import unittest2 as unittest
-else:
-    import unittest
+import unittest
 
 with_png_app = with_app(srcdir='tests/docs/basic',
                         buildername='html',
@@ -29,7 +25,8 @@ class TestSphinxcontribActdiagHTML(unittest.TestCase):
         """
         app.builder.build_all()
         source = (app.outdir / 'index.html').read_text(encoding='utf-8')
-        self.assertRegexpMatches(source, '<div><img .*? src="_images/.*?.png" .*?/></div>')
+        self.assertRegexpMatches(source, (r'<div class="align-default">'
+                                          r'<img .*? src="_images/.*?.png" .*?/></div>'))
 
     @with_app(srcdir='tests/docs/subdir', buildername='html', write_docstring=True)
     def test_build_png_image_in_subdir(self, app, status, warning):
@@ -40,7 +37,8 @@ class TestSphinxcontribActdiagHTML(unittest.TestCase):
         """
         app.builder.build_all()
         source = (app.outdir / 'subdir' / 'index.html').read_text(encoding='utf-8')
-        self.assertRegexpMatches(source, '<div><img .*? src="\.\./_images/.*?.png" .*?/></div>')
+        self.assertRegexpMatches(source, (r'<div class="align-default">'
+                                          r'<img .*? src="\.\./_images/.*?.png" .*?/></div>'))
 
     @with_png_app
     def test_width_option_on_png(self, app, status, warning):
@@ -52,8 +50,9 @@ class TestSphinxcontribActdiagHTML(unittest.TestCase):
         """
         app.builder.build_all()
         source = (app.outdir / 'index.html').read_text(encoding='utf-8')
-        self.assertRegexpMatches(source, ('<div><a class="reference internal image-reference" href="(.*?.png)">'
-                                          '<img height="140.0" src="\\1" width="128.0" /></a></div>'))
+        self.assertRegexpMatches(source, (r'<div class="align-default">'
+                                          r'<a class="reference internal image-reference" href="(.*?.png)">'
+                                          r'<img height="140.0" src="\1" width="128.0" /></a></div>'))
 
     @with_png_app
     def test_height_option_on_png(self, app, status, warning):
@@ -65,8 +64,9 @@ class TestSphinxcontribActdiagHTML(unittest.TestCase):
         """
         app.builder.build_all()
         source = (app.outdir / 'index.html').read_text(encoding='utf-8')
-        self.assertRegexpMatches(source, ('<div><a class="reference internal image-reference" href="(.*?.png)">'
-                                          '<img height="140.0" src="\\1" width="128.0" /></a></div>'))
+        self.assertRegexpMatches(source, (r'<div class="align-default">'
+                                          r'<a class="reference internal image-reference" href="(.*?.png)">'
+                                          r'<img height="140.0" src="\1" width="128.0" /></a></div>'))
 
     @with_png_app
     def test_width_option_and_height_option_on_png(self, app, status, warning):
@@ -79,8 +79,9 @@ class TestSphinxcontribActdiagHTML(unittest.TestCase):
         """
         app.builder.build_all()
         source = (app.outdir / 'index.html').read_text(encoding='utf-8')
-        self.assertRegexpMatches(source, ('<div><a class="reference internal image-reference" href="(.*?.png)">'
-                                          '<img height="200.0" src="\\1" width="100.0" /></a></div>'))
+        self.assertRegexpMatches(source, (r'<div class="align-default">'
+                                          r'<a class="reference internal image-reference" href="(.*?.png)">'
+                                          r'<img height="200.0" src="\1" width="100.0" /></a></div>'))
 
     @with_png_app
     def test_scale_option_on_png(self, app, status, warning):
@@ -92,8 +93,9 @@ class TestSphinxcontribActdiagHTML(unittest.TestCase):
         """
         app.builder.build_all()
         source = (app.outdir / 'index.html').read_text(encoding='utf-8')
-        self.assertRegexpMatches(source, ('<div><a class="reference internal image-reference" href="(.*?.png)">'
-                                          '<img height="70.0" src="\\1" width="64.0" /></a></div>'))
+        self.assertRegexpMatches(source, (r'<div class="align-default">'
+                                          r'<a class="reference internal image-reference" href="(.*?.png)">'
+                                          r'<img height="70.0" src="\1" width="64.0" /></a></div>'))
 
     @with_png_app
     def test_width_option_and_scale_option_on_png(self, app, status, warning):
@@ -106,8 +108,9 @@ class TestSphinxcontribActdiagHTML(unittest.TestCase):
         """
         app.builder.build_all()
         source = (app.outdir / 'index.html').read_text(encoding='utf-8')
-        self.assertRegexpMatches(source, ('<div><a class="reference internal image-reference" href="(.*?.png)">'
-                                          '<img height="7.65625" src="\\1" width="7.0" /></a></div>'))
+        self.assertRegexpMatches(source, (r'<div class="align-default">'
+                                          r'<a class="reference internal image-reference" href="(.*?.png)">'
+                                          r'<img height="7.65625" src="\1" width="7.0" /></a></div>'))
 
     @with_png_app
     def test_align_option_on_png(self, app, status, warning):
@@ -119,7 +122,7 @@ class TestSphinxcontribActdiagHTML(unittest.TestCase):
         """
         app.builder.build_all()
         source = (app.outdir / 'index.html').read_text(encoding='utf-8')
-        self.assertRegexpMatches(source, '<div align="center" class="align-center"><img .*? /></div>')
+        self.assertRegexpMatches(source, r'<div class="align-center"><img .*? /></div>')
 
     @with_png_app
     def test_align_option_and_width_option_on_png(self, app, status, warning):
@@ -132,9 +135,9 @@ class TestSphinxcontribActdiagHTML(unittest.TestCase):
         """
         app.builder.build_all()
         source = (app.outdir / 'index.html').read_text(encoding='utf-8')
-        self.assertRegexpMatches(source, ('<div align="center" class="align-center">'
-                                          '<a class="reference internal image-reference" href="(.*?.png)">'
-                                          '<img height="140.0" src="\\1" width="128.0" /></a></div>'))
+        self.assertRegexpMatches(source, (r'<div class="align-center">'
+                                          r'<a class="reference internal image-reference" href="(.*?.png)">'
+                                          r'<img height="140.0" src="\1" width="128.0" /></a></div>'))
 
     @with_png_app
     def test_name_option_on_png(self, app, status, warning):
@@ -146,7 +149,7 @@ class TestSphinxcontribActdiagHTML(unittest.TestCase):
         """
         app.builder.build_all()
         source = (app.outdir / 'index.html').read_text(encoding='utf-8')
-        self.assertRegexpMatches(source, '<div><img .*? id="target" src=".*?" .*? /></div>')
+        self.assertRegexpMatches(source, r'<div class="align-default"><img .*? id="target" src=".*?" .*? /></div>')
 
     @with_png_app
     def test_name_option_and_width_option_on_png(self, app, status, warning):
@@ -159,8 +162,9 @@ class TestSphinxcontribActdiagHTML(unittest.TestCase):
         """
         app.builder.build_all()
         source = (app.outdir / 'index.html').read_text(encoding='utf-8')
-        self.assertRegexpMatches(source, ('<div><a class="reference internal image-reference" href="(.*?.png)">'
-                                          '<img height="140.0" id="target" src="\\1" width="128.0" /></a></div>'))
+        self.assertRegexpMatches(source, (r'<div class="align-default">'
+                                          r'<a class="reference internal image-reference" href="(.*?.png)">'
+                                          r'<img height="140.0" id="target" src="\1" width="128.0" /></a></div>'))
 
     @with_png_app
     def test_href_and_scale_option_on_png(self, app, status, warning):
@@ -173,11 +177,12 @@ class TestSphinxcontribActdiagHTML(unittest.TestCase):
         """
         app.builder.build_all()
         source = (app.outdir / 'index.html').read_text(encoding='utf-8')
-        self.assertRegexpMatches(source, ('<div><a class="reference internal image-reference" href="(.*?.png)">'
-                                          '<map name="(map_\d+)">'
-                                          '<area shape="rect" coords="32.0,60.0,96.0,80.0" '
-                                          'href="http://blockdiag.com/"></map>'
-                                          '<img .*? src="\\1" usemap="#\\2" .*?/></a></div>'))
+        self.assertRegexpMatches(source, (r'<div class="align-default">'
+                                          r'<a class="reference internal image-reference" href="(.*?.png)">'
+                                          r'<map name="(map_\d+)">'
+                                          r'<area shape="rect" coords="32.0,60.0,96.0,80.0" '
+                                          r'href="http://blockdiag.com/"></map>'
+                                          r'<img .*? src="\1" usemap="#\2" .*?/></a></div>'))
 
     @with_png_app
     def test_reftarget_in_href_on_png1(self, app, status, warning):
@@ -194,9 +199,9 @@ class TestSphinxcontribActdiagHTML(unittest.TestCase):
         """
         app.builder.build_all()
         source = (app.outdir / 'index.html').read_text(encoding='utf-8')
-        self.assertRegexpMatches(source, ('<div><map name="(map_\d+)">'
-                                          '<area shape="rect" coords="64.0,120.0,192.0,160.0" href="#target"></map>'
-                                          '<img .*? src=".*?.png" usemap="#\\1" .*?/></div>'))
+        self.assertRegexpMatches(source, (r'<div class="align-default"><map name="(map_\d+)">'
+                                          r'<area shape="rect" coords="64.0,120.0,192.0,160.0" href="#target"></map>'
+                                          r'<img .*? src=".*?.png" usemap="#\1" .*?/></div>'))
 
     @with_png_app
     def test_reftarget_in_href_on_png2(self, app, status, warning):
@@ -213,9 +218,9 @@ class TestSphinxcontribActdiagHTML(unittest.TestCase):
         """
         app.builder.build_all()
         source = (app.outdir / 'index.html').read_text(encoding='utf-8')
-        self.assertRegexpMatches(source, ('<div><map name="(map_\d+)">'
-                                          '<area shape="rect" coords="64.0,120.0,192.0,160.0" href="#hello-world">'
-                                          '</map><img .*? src=".*?.png" usemap="#\\1" .*?/></div>'))
+        self.assertRegexpMatches(source, (r'<div class="align-default"><map name="(map_\d+)">'
+                                          r'<area shape="rect" coords="64.0,120.0,192.0,160.0" href="#hello-world">'
+                                          r'</map><img .*? src=".*?.png" usemap="#\1" .*?/></div>'))
 
     @with_png_app
     def test_missing_reftarget_in_href_on_png(self, app, status, warning):
@@ -227,7 +232,7 @@ class TestSphinxcontribActdiagHTML(unittest.TestCase):
         """
         app.builder.build_all()
         source = (app.outdir / 'index.html').read_text(encoding='utf-8')
-        self.assertRegexpMatches(source, ('<div><img .*? src=".*?.png" .*?/></div>'))
+        self.assertRegexpMatches(source, r'<div class="align-default"><img .*? src=".*?.png" .*?/></div>')
         self.assertIn('undefined label: unknown_target', warning.getvalue())
 
     @with_svg_app
@@ -239,7 +244,7 @@ class TestSphinxcontribActdiagHTML(unittest.TestCase):
         """
         app.builder.build_all()
         source = (app.outdir / 'index.html').read_text(encoding='utf-8')
-        self.assertRegexpMatches(source, '<div><svg .*?>')
+        self.assertRegexpMatches(source, r'<div class="align-default"><svg .*?>')
 
     @with_svg_app
     def test_width_option_on_svg(self, app, status, warning):
@@ -251,7 +256,8 @@ class TestSphinxcontribActdiagHTML(unittest.TestCase):
         """
         app.builder.build_all()
         source = (app.outdir / 'index.html').read_text(encoding='utf-8')
-        self.assertRegexpMatches(source, '<div><svg height="140.0" viewBox="0 0 256 280" width="128.0" .*?>')
+        self.assertRegexpMatches(source, (r'<div class="align-default">'
+                                          r'<svg height="140.0" viewBox="0 0 256 280" width="128.0" .*?>'))
 
     @with_svg_app
     def test_height_option_on_svg(self, app, status, warning):
@@ -263,7 +269,8 @@ class TestSphinxcontribActdiagHTML(unittest.TestCase):
         """
         app.builder.build_all()
         source = (app.outdir / 'index.html').read_text(encoding='utf-8')
-        self.assertRegexpMatches(source, '<div><svg height="140.0" viewBox="0 0 256 280" width="128.0" .*?>')
+        self.assertRegexpMatches(source, (r'<div class="align-default">'
+                                          r'<svg height="140.0" viewBox="0 0 256 280" width="128.0" .*?>'))
 
     @with_svg_app
     def test_width_option_and_height_option_on_svg(self, app, status, warning):
@@ -276,7 +283,8 @@ class TestSphinxcontribActdiagHTML(unittest.TestCase):
         """
         app.builder.build_all()
         source = (app.outdir / 'index.html').read_text(encoding='utf-8')
-        self.assertRegexpMatches(source, '<div><svg height="200.0" viewBox="0 0 256 280" width="100.0" .*?>')
+        self.assertRegexpMatches(source, (r'<div class="align-default">'
+                                          r'<svg height="200.0" viewBox="0 0 256 280" width="100.0" .*?>'))
 
     @with_svg_app
     def test_scale_option_on_svg(self, app, status, warning):
@@ -288,7 +296,8 @@ class TestSphinxcontribActdiagHTML(unittest.TestCase):
         """
         app.builder.build_all()
         source = (app.outdir / 'index.html').read_text(encoding='utf-8')
-        self.assertRegexpMatches(source, '<div><svg height="70.0" viewBox="0 0 256 280" width="64.0" .*?>')
+        self.assertRegexpMatches(source, (r'<div class="align-default">'
+                                          r'<svg height="70.0" viewBox="0 0 256 280" width="64.0" .*?>'))
 
     @with_svg_app
     def test_width_option_and_scale_option_on_svg(self, app, status, warning):
@@ -301,7 +310,8 @@ class TestSphinxcontribActdiagHTML(unittest.TestCase):
         """
         app.builder.build_all()
         source = (app.outdir / 'index.html').read_text(encoding='utf-8')
-        self.assertRegexpMatches(source, '<div><svg height="7.65625" viewBox="0 0 256 280" width="7.0" .*?>')
+        self.assertRegexpMatches(source, (r'<div class="align-default">'
+                                          r'<svg height="7.65625" viewBox="0 0 256 280" width="7.0" .*?>'))
 
     @with_svg_app
     def test_align_option_on_svg(self, app, status, warning):
@@ -313,7 +323,7 @@ class TestSphinxcontribActdiagHTML(unittest.TestCase):
         """
         app.builder.build_all()
         source = (app.outdir / 'index.html').read_text(encoding='utf-8')
-        self.assertRegexpMatches(source, '<div align="center" class="align-center"><svg .*?>')
+        self.assertRegexpMatches(source, r'<div class="align-center"><svg .*?>')
 
     @with_svg_app
     def test_name_option_on_svg(self, app, status, warning):
@@ -325,7 +335,7 @@ class TestSphinxcontribActdiagHTML(unittest.TestCase):
         """
         app.builder.build_all()
         source = (app.outdir / 'index.html').read_text(encoding='utf-8')
-        self.assertRegexpMatches(source, '<div><span id="target"></span><svg .*?>')
+        self.assertRegexpMatches(source, r'<div class="align-default"><span id="target"></span><svg .*?>')
 
     @with_svg_app
     def test_reftarget_in_href_on_svg1(self, app, status, warning):
@@ -342,7 +352,7 @@ class TestSphinxcontribActdiagHTML(unittest.TestCase):
         """
         app.builder.build_all()
         source = (app.outdir / 'index.html').read_text(encoding='utf-8')
-        self.assertRegexpMatches(source, '<a xlink:href="#target">\\n\\s*<rect .*?>\\n\\s*</a>')
+        self.assertRegexpMatches(source, r'<a xlink:href="#target">\n\s*<rect .*?>\n\s*</a>')
 
     @with_svg_app
     def test_reftarget_in_href_on_svg2(self, app, status, warning):
@@ -359,7 +369,7 @@ class TestSphinxcontribActdiagHTML(unittest.TestCase):
         """
         app.builder.build_all()
         source = (app.outdir / 'index.html').read_text(encoding='utf-8')
-        self.assertRegexpMatches(source, '<a xlink:href="#hello-world">\\n\\s*<rect .*?>\\n\\s*</a>')
+        self.assertRegexpMatches(source, r'<a xlink:href="#hello-world">\n\s*<rect .*?>\n\s*</a>')
 
     @with_svg_app
     def test_missing_reftarget_in_href_on_svg(self, app, status, warning):
@@ -371,10 +381,7 @@ class TestSphinxcontribActdiagHTML(unittest.TestCase):
         """
         app.builder.build_all()
         source = (app.outdir / 'index.html').read_text(encoding='utf-8')
-        if sys.version_info < (3, 0):
-            self.assertNotRegexpMatches(source, '<a xlink:href="#hello-world">\\n\\s*<rect .*?>\\n\\s*</a>')
-        else:
-            self.assertNotRegex(source, '<a xlink:href="#hello-world">\\n\\s*<rect .*?>\\n\\s*</a>')
+        self.assertNotRegex(source, r'<a xlink:href="#hello-world">\n\s*<rect .*?>\n\s*</a>')
         self.assertIn('undefined label: unknown_target', warning.getvalue())
 
     @with_svg_app
@@ -395,4 +402,4 @@ class TestSphinxcontribActdiagHTML(unittest.TestCase):
         """
         app.builder.build_all()
         source = (app.outdir / 'index.html').read_text(encoding='utf-8')
-        self.assertRegexpMatches(source, '<text[^>]+>A_foo</text>')  # 2nd diagram has a node labeled 'A_foo'.
+        self.assertRegexpMatches(source, r'<text[^>]+>A_foo</text>')  # 2nd diagram has a node labeled 'A_foo'.
