@@ -3,26 +3,23 @@
 import os
 import re
 from sphinx_testing import with_app
-from blockdiag.utils.compat import u
 
-import sys
-if sys.version_info < (2, 7):
-    import unittest2 as unittest
-else:
-    import unittest
+import unittest
+
+CR = '\r?\n'
 
 actdiag_fontpath = '/usr/share/fonts/truetype/ipafont/ipagp.ttf'
 with_png_app = with_app(srcdir='tests/docs/basic',
                         buildername='latex',
                         write_docstring=True,
                         confoverrides={
-                            'latex_documents': [('index', 'test.tex', u(''), u('test'), 'manual')],
+                            'latex_documents': [('index', 'test.tex', '', 'test', 'manual')],
                         })
 with_pdf_app = with_app(srcdir='tests/docs/basic',
                         buildername='latex',
                         write_docstring=True,
                         confoverrides={
-                            'latex_documents': [('index', 'test.tex', u(''), u('test'), 'manual')],
+                            'latex_documents': [('index', 'test.tex', '', 'test', 'manual')],
                             'actdiag_latex_image_format': 'PDF',
                             'actdiag_fontpath': actdiag_fontpath,
                         })
@@ -30,7 +27,7 @@ with_oldpdf_app = with_app(srcdir='tests/docs/basic',
                            buildername='latex',
                            write_docstring=True,
                            confoverrides={
-                               'latex_documents': [('index', 'test.tex', u(''), u('test'), 'manual')],
+                               'latex_documents': [('index', 'test.tex', '', 'test', 'manual')],
                                'actdiag_tex_image_format': 'PDF',
                                'actdiag_fontpath': actdiag_fontpath,
                            })
@@ -46,10 +43,9 @@ class TestSphinxcontribActdiagLatex(unittest.TestCase):
         """
         app.builder.build_all()
         source = (app.outdir / 'test.tex').read_text(encoding='utf-8')
-        self.assertRegexpMatches(source, '\\\\includegraphics{actdiag-.*?.png}')
+        self.assertRegexpMatches(source, r'\\sphinxincludegraphics{{actdiag-.*?}.png}')
 
     @unittest.skipUnless(os.path.exists(actdiag_fontpath), "TrueType font not found")
-    @unittest.skipIf(sys.version_info[:2] == (3, 2), "reportlab does not support python 3.2")
     @with_pdf_app
     def test_build_pdf_image1(self, app, status, warning):
         """
@@ -59,10 +55,9 @@ class TestSphinxcontribActdiagLatex(unittest.TestCase):
         """
         app.builder.build_all()
         source = (app.outdir / 'test.tex').read_text(encoding='utf-8')
-        self.assertRegexpMatches(source, '\\\\includegraphics{actdiag-.*?.pdf}')
+        self.assertRegexpMatches(source, r'\\sphinxincludegraphics{{actdiag-.*?}.pdf}')
 
     @unittest.skipUnless(os.path.exists(actdiag_fontpath), "TrueType font not found")
-    @unittest.skipIf(sys.version_info[:2] == (3, 2), "reportlab does not support python 3.2")
     @with_oldpdf_app
     def test_build_pdf_image2(self, app, status, warning):
         """
@@ -72,7 +67,7 @@ class TestSphinxcontribActdiagLatex(unittest.TestCase):
         """
         app.builder.build_all()
         source = (app.outdir / 'test.tex').read_text(encoding='utf-8')
-        self.assertRegexpMatches(source, '\\\\includegraphics{actdiag-.*?.pdf}')
+        self.assertRegexpMatches(source, r'\\sphinxincludegraphics{{actdiag-.*?}.pdf}')
 
     @with_png_app
     def test_width_option(self, app, status, warning):
@@ -84,7 +79,7 @@ class TestSphinxcontribActdiagLatex(unittest.TestCase):
         """
         app.builder.build_all()
         source = (app.outdir / 'test.tex').read_text(encoding='utf-8')
-        self.assertRegexpMatches(source, '\\\\includegraphics\\[width=3cm\\]{actdiag-.*?.png}')
+        self.assertRegexpMatches(source, r'\\sphinxincludegraphics\[width=3cm\]{{actdiag-.*?}.png}')
 
     @with_png_app
     def test_height_option(self, app, status, warning):
@@ -96,7 +91,7 @@ class TestSphinxcontribActdiagLatex(unittest.TestCase):
         """
         app.builder.build_all()
         source = (app.outdir / 'test.tex').read_text(encoding='utf-8')
-        self.assertRegexpMatches(source, '\\\\includegraphics\\[height=4cm\\]{actdiag-.*?.png}')
+        self.assertRegexpMatches(source, r'\\sphinxincludegraphics\[height=4cm\]{{actdiag-.*?}.png}')
 
     @with_png_app
     def test_scale_option(self, app, status, warning):
@@ -108,7 +103,7 @@ class TestSphinxcontribActdiagLatex(unittest.TestCase):
         """
         app.builder.build_all()
         source = (app.outdir / 'test.tex').read_text(encoding='utf-8')
-        self.assertRegexpMatches(source, '\\\\scalebox{0.500000}{\\\\includegraphics{actdiag-.*?.png}}')
+        self.assertRegexpMatches(source, r'\\sphinxincludegraphics\[scale=0.5\]{{actdiag-.*?}.png}')
 
     @with_png_app
     def test_align_option_left(self, app, status, warning):
@@ -120,7 +115,8 @@ class TestSphinxcontribActdiagLatex(unittest.TestCase):
         """
         app.builder.build_all()
         source = (app.outdir / 'test.tex').read_text(encoding='utf-8')
-        self.assertRegexpMatches(source, '{\\\\includegraphics{actdiag-.*?.png}\\\\hfill}')
+        self.assertRegexpMatches(source, (r'{\\sphinxincludegraphics{{actdiag-.*?}.png}'
+                                          r'\\hspace\*{\\fill}}'))
 
     @with_png_app
     def test_align_option_center(self, app, status, warning):
@@ -132,7 +128,9 @@ class TestSphinxcontribActdiagLatex(unittest.TestCase):
         """
         app.builder.build_all()
         source = (app.outdir / 'test.tex').read_text(encoding='utf-8')
-        self.assertRegexpMatches(source, '{\\\\hfill\\\\includegraphics{actdiag-.*?.png}\\\\hfill}')
+        self.assertRegexpMatches(source, (r'{\\hspace\*{\\fill}'
+                                          r'\\sphinxincludegraphics{{actdiag-.*?}.png}'
+                                          r'\\hspace\*{\\fill}}'))
 
     @with_png_app
     def test_align_option_right(self, app, status, warning):
@@ -144,7 +142,8 @@ class TestSphinxcontribActdiagLatex(unittest.TestCase):
         """
         app.builder.build_all()
         source = (app.outdir / 'test.tex').read_text(encoding='utf-8')
-        self.assertRegexpMatches(source, '{\\\\hfill\\\\includegraphics{actdiag-.*?.png}}')
+        self.assertRegexpMatches(source, (r'{\\hspace\*{\\fill}'
+                                          r'\\sphinxincludegraphics{{actdiag-.*?}.png}'))
 
     @with_png_app
     def test_caption_option(self, app, status, warning):
@@ -156,10 +155,13 @@ class TestSphinxcontribActdiagLatex(unittest.TestCase):
         """
         app.builder.build_all()
         source = (app.outdir / 'test.tex').read_text(encoding='utf-8')
-        self.assertRegexpMatches(source, '\\\\includegraphics{actdiag-.*?.png}')
 
-        figure = re.compile('\\\\begin{figure}\\[htbp\\]\r?\n\\\\centering.*?'
-                            '\\\\caption{hello world}\\\\end{figure}', re.DOTALL)
+        figure = re.compile((r'\\begin{figure}\[htbp\]' + CR +
+                             r'\\centering' + CR +
+                             r'\\capstart' + CR + CR +
+                             r'\\noindent\\sphinxincludegraphics{{actdiag-.*?}.png}' + CR +
+                             r'\\caption{hello world}\\label{\\detokenize{index:id1}}\\end{figure}'),
+                            re.DOTALL)
         self.assertRegexpMatches(source, figure)
 
     @with_png_app
@@ -173,10 +175,12 @@ class TestSphinxcontribActdiagLatex(unittest.TestCase):
         """
         app.builder.build_all()
         source = (app.outdir / 'test.tex').read_text(encoding='utf-8')
-        self.assertRegexpMatches(source, '\\\\includegraphics{actdiag-.*?.png}')
 
-        figure = re.compile('\\\\begin{figure}\\[htbp\\]\\\\begin{flushleft}.*?'
-                            '\\\\caption{hello world}\\\\end{flushleft}\\\\end{figure}', re.DOTALL)
+        figure = re.compile((r'\\begin{wrapfigure}{l}{0pt}' + CR +
+                             r'\\centering' + CR +
+                             r'\\noindent\\sphinxincludegraphics{{actdiag-.*?}.png}' + CR +
+                             r'\\caption{hello world}\\label{\\detokenize{index:id1}}\\end{wrapfigure}'),
+                            re.DOTALL)
         self.assertRegexpMatches(source, figure)
 
     @with_png_app
@@ -189,4 +193,4 @@ class TestSphinxcontribActdiagLatex(unittest.TestCase):
         """
         app.builder.build_all()
         source = (app.outdir / 'test.tex').read_text(encoding='utf-8')
-        self.assertRegexpMatches(source, '\\\\includegraphics{actdiag-.*?.png}')
+        self.assertRegexpMatches(source, r'\\sphinxincludegraphics{{actdiag-.*?}.png}')
